;--------------------------------------------------------------------------------------
; STM32L5xx_S_OPT.s: STM32L5xx Flash Option Bytes security enabled, V0.0.1 (C) 2020 ARM
;--------------------------------------------------------------------------------------

; <<< Use Configuration Wizard in Context Menu >>>

;// <e> Flash Option Bytes
FLASH_OPT       EQU     1

;// <h> Read Out Protection
;//     <i> Read protection is used to protect the software code stored in Flash memory.
;//   <o0.0..7> RDP
;//     <i> Level 0: No Protection
;//     <i> Level 1: Read Protection of Memories (debug features limited)
;//     <i> Level 2: Chip Protection (debug and boot in RAM features disabled)
;//          <0xAA=> Level 0 (no protection)
;//          <0x55=> Level 0.5 (read protection not active, only non-secure access is possible)
;//          <0x00=> Level 1 (read protection of memories)
;//          <0xCC=> Level 2 (chip protection)
;// </h>

;// <h> BOR Level
;//     <i>These bits contain the VDD supply level threshold that activates/releases the reset.
;//   <o0.8..10> BOR_LEV
;//          <0=> BOR Level 0 (reset level threshold is around 1.7 V)
;//          <1=> BOR Level 1 (reset level threshold is around 2.0 V)
;//          <2=> BOR Level 2 (reset level threshold is around 2.2 V)
;//          <3=> BOR Level 3 (reset level threshold is around 2.5 V)
;//          <4=> BOR Level 4 (reset level threshold is around 2.8 V)
;// </h>

;// <h> User Configuration
;//   <o0.31> TZEN
;//     <i> Global TrustZone security enable
;//   <o0.28> PA15_PUPEN
;//     <i> : PA15 pull-up enable
;//   <o0.27> nBOOT0
;//     <i> nBOOT0 option bit
;//   <o0.26> nSWBOOT0
;//     <i> Software BOOT0
;//          <0=> Option bit nBOOT0
;//          <1=> PH3/BOOT0 pin
;//   <o0.25> SRAM2_RST
;//     <i> SRAM2 Erase on system reset
;//          <0=> SRAM2 erased
;//          <1=> SRAM2 not erased
;//   <o0.24> SRAM2_PE
;//     <i> SRAM2 parity check
;//          <0=> SRAM2 parity check enabled
;//          <1=> SRAM2 parity check disabled
;//   <o0.22> DBANK
;//     <i> This bit can only be written when all protection (secure, HDP) are disabled
;//          <0=> Single bank mode
;//          <1=> Dual bank mode
;//   <o0.21> DB256:
;//     <i> Dual-bank on 256 Kbytes Flash memory devices
;//          <0=> 256 Kbytes single Flash: contiguous address in bank1
;//          <1=> 256 Kbytes dual-bank Flash with contiguous addresses
;//   <o0.20> SWAP_BANK
;//     <i> Swap banks
;//          <0=> Bank 1 and bank 2 address are not swapped
;//          <1=> Bank 1 and bank 2 address are swapped
;//   <o0.19> WWDG_SW
;//     <i> Window watchdog selection
;//          <0=> Hardware window watchdog
;//          <1=> Software window watchdog
;//   <o0.18> IWDG_STDBY
;//     <i> Independent watchdog counter freeze in Standby mode
;//          <0=> IWDG counter is frozen in Standby mode
;//          <1=> IWDG counter is running in Standby mode
;//   <o0.17> IWDG_STOP
;//     <i> Independent watchdog counter freeze in Stop mode
;//          <0=> IWDG counter is frozen in STOP mode
;//          <1=> IWDG counter is running in STOP mode
;//   <o0.16> IWDG_SW
;//     <i> Independent watchdog selection
;//          <0=> Hardware independant watchdog
;//          <1=> Software independant watchdog
;//   <o0.14> nRST_SHDW
;//     <i> Generate Reset when entering Shutdown Mode
;//          <0=> Reset generated
;//          <1=> Reset not generated
;//   <o0.13> nRST_STDBY
;//     <i> Generate Reset when entering Standby Mode
;//          <0=> Reset generated
;//          <1=> Reset not generated
;//   <o0.12> nRST_STOP
;//     <i> Generate Reset when entering STOP Mode
;//          <0=> Reset generated
;//          <1=> Reset not generated
;//
;//   <o1.31> HDP1EN
;//     <i> Hide protection first area enable
;//   <o1.16..22> HDP1_PEND
;//     <i> End page of first hide protection area
;//     <i> DBANK=1: HDP1_PEND contains the last page of the HDP area in bank1.
;//     <i> DBANK=0: HDP1_PEND contains the last page of the first HDP area for all memory.
;//
;//   <o2.31> HDP2EN
;//     <i> Hide protection first area enable
;//   <o2.16..22> HDP2_PEND
;//     <i> End page of first hide protection area
;//     <i> DBANK=1: HDP2_PEND contains the last page of the HDP area in bank2.
;//     <i> DBANK=0: HDP2_PEND contains the last page of the second HDP area for all memory.
;//
;//   <o3.7..31> NSBOOTADD0
;//     <i> Non-secure Boot base address 0
;//     <i> The non-secure boot memory address can be programmed to any address in the valid address range with a granularity of 128 bytes.
;//     <i> The NSBOOTADD0[24:0] correspond to address [31:7].
;//     <i> The NSBOOTADD0 option bytes are selected following the Boot pin or nSWBOOTO state.
;//
;//   <o4.7..31> NSBOOTADD1
;//     <i> Non-secure Boot base address 1
;//     <i> The non-secure boot memory address can be programmed to any address in the valid address range with a granularity of 128 bytes.
;//     <i> The NSBOOTADD1[24:0] correspond to address [31:7].
;//     <i> The NSBOOTADD1 option bytes are selected following the Boot pin or nSWBOOTO state.
;//
;//   <o5.7..31> SECBOOTADD0
;//     <i> Secure boot base address 0
;//     <i> The secure boot memory address can be programmed to any address in the valid address range with a granularity of 128 bytes.
;//     <i> The SECBOOTADD0[24:0] correspond to address [31:7].
;//     <i> The SECBOOTADD0 option bytes are selected following the boot pin or nSWBOOTO state.
;//   <o5.0> BOOT_LOCK
;//     <i> BOOT LOCK
;//     <i> When set, the boot is always forced to base address value programmed in SECBOOTADD0[24:0] option bytes whatever the boot selection option.
;//     <i> When set, it cannot be cleared.
;// </h>
FLASH_OPTR          EQU  0xFFEFF8AA       ; reset value 0xFFEFF8AA
FLASH_SECWM1R2      EQU  0x7F807F80       ; reset value 0x7F807F80
FLASH_SECWM2R2      EQU  0x7F807F80       ; reset value 0x7F807F80
FLASH_NSBOOTADD0R   EQU  0x0800007F       ; reset value 0x0800007F
FLASH_NSBOOTADD1R   EQU  0x0BF9007F       ; reset value 0x0BF9007F
FLASH_SECBOOTADD0R  EQU  0x0C00007C       ; reset value 0x0C00007C

;// <h> Secure Area 1
;//   <o0.16..22> SECWM1_PEND
;//     <i> End page of first secure area
;//     <i> DBANK=1: SECWM1_PEND contains the last page of the secure area in bank 1.
;//     <i> DBANK=0: SECWM1_PEND contains the last page of the first secure area for all memory.
;//   <o0.0..6>   SECWM1_PSTRT
;//     <i> Start page of first secure area
;//     <i> DBANK=1: SECWM1_PSTRT contains the first page of the secure area in bank 1.
;//     <i> DBANK=0: SECWM1_PSTRT contains the first page of the first secure area for all memory.
;// </h>
FLASH_SECWM1R1      EQU  0xFFFFFF80       ; reset value 0xFFFFFF80

;// <h> Write Protection 1
;//   <o0.16..22> WRP1A_PEND
;//     <i> Bank 1 WPR first area "A" end page
;//     <i> DBANK=1: WRP1A_PEND contains the last page of the first WPR area in bank 1.
;//     <i> DBANK=0: WRP1A_PEND contains the last page of the first WPR area for all memory.
;//   <o0.0..6>   WRP1A_PSTRT
;//     <i> bank 1 WPR first area "A" start page
;//     <i> DBANK=1: WRP1A_PSTRT contains the first page of the first WPR area for bank1.
;//     <i> DBANK=0: WRP1A_PSTRT contains the first page of the first WPR area for all memory.
;//   <o1.16..22> WRP1B_PEND
;//     <i> Bank 1 WRP second area "B" end page
;//     DBANK=1: WRP1B_PEND contains the last page of the second WRP area in bank1.
;//     DBANK=0: WRP1B_PEND contains the last page of the second WRP area for all memory.
;//   <o1.0..6>   WRP1B_PSTRT
;//     <i> Bank 1 WRP second area "B" start page
;//     DBANK=1: WRP1B_PSTRT contains the first page of the second WRP area for bank1.
;//     DBANK=0: WRP1B_PSTRT contains the first page of the second WRP area for all memory.
;// </h>
FLASH_WRP1AR        EQU  0xFF80FFFF       ; reset value 0xFF80FFFF
FLASH_WRP1BR        EQU  0xFF80FFFF       ; reset value 0xFF80FFFF

;// <h> Secure Area 2
;//   <o0.16..22> SECWM2_PEND
;//     <i> End page of second secure area
;//     <i> DBANK=1: SECWM2_PEND contains the last page of the secure area in bank 2.
;//     <i> DBANK=0: SECWM2_PEND contains the last page of the second secure area for all memory.
;//   <o0.0..6>   SECWM2_PSTRT
;//     <i> Start page of second secure area
;//     <i> DBANK=1: SECWM2_PSTRT contains the first page of the secure area in bank 2.
;//     <i> DBANK=0: SECWM2_PSTRT contains the first page of the second secure area for all memory.
;// </h>
FLASH_SECWM2R1      EQU  0xFFFFFF80       ; reset value 0xFFFFFF80

;// <h> Write Protection 2
;//   <o0.16..22> WRP2A_PEND
;//     <i> Bank 2 WPR first area "A" end page
;//     DBANK=1: WRP2A_PEND contains the last page of the first WRP area in bank2.
;//     DBANK=0: WRP2A_PEND contains the last page of the third WRP area for all memory.
;//   <o0.0..6>   WRP2A_PSTRT
;//     <i> Bank 2 WPR first area "A" start page
;//     DBANK=1: WRP2A_PSTRT contains the first page of the first WRP area for bank2.
;//     DBANK=0: WRP2A_PSTRT contains the first page of the third WRP area for all memory.
;//   <o1.16..22> WRP2B_PEND
;//     <i> Bank 2 WPR second area "B" end page
;//     DBANK=1: WRP2B_PEND contains the last page of the second WRP area in bank 2.
;//     DBANK=0: WRP2B_PEND contains the last page of the fourth WRP area for all memory.
;//   <o1.0..6>   WRP2B_PSTRT
;//     <i> Bank 2 WPR second area "B" start page
;//     DBANK=1: WRP2B_PSTRT contains the first page of the second WRP area for bank 2.
;//     DBANK=0: WRP2B_PSTRT contains the first page of the fourth WRP area for all memory.
;// </h>
FLASH_WRP2AR        EQU  0xFF80FFFF       ; reset value 0xFF80FFFF
FLASH_WRP2BR        EQU  0xFF80FFFF       ; reset value 0xFF80FFFF

;// </e>


                IF      FLASH_OPT <> 0
                AREA    |.ARM.__AT_0x1FF00000|, CODE, READONLY
                DCD     FLASH_OPTR
                DCD     FLASH_SECWM1R2
                DCD     FLASH_SECWM2R2
                DCD     FLASH_NSBOOTADD0R
                DCD     FLASH_NSBOOTADD1R
                DCD     FLASH_SECBOOTADD0R
                DCD     FLASH_SECWM1R1
                DCD     FLASH_WRP1AR
                DCD     FLASH_WRP1BR
                DCD     FLASH_SECWM2R1
                DCD     FLASH_WRP2AR
                DCD     FLASH_WRP2BR
                ENDIF

                END
